#
# spec file for package syncthing
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           syncthing
Version:        1.29.7
Release:        1.1
Summary:        Continuous File Synchronisation
License:        MPL-2.0
Group:          Productivity/Networking/File-Sharing
URL:            https://syncthing.net/
Source:         https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-source-v%{version}.tar.gz
# signature can not be validated at the moment, see changelog entry from "Jan 16 11:32:55 UTC 2025" and https://github.com/syncthing/syncthing/issues/9902
#Source1:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-source-v%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{name}-relaysrv-user.conf
Patch0:         harden_strelaysrv.service.patch
Patch1:         harden_syncthing@.service.patch
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  update-desktop-files
BuildRequires:  golang(API) >= 1.14
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}

%description
Syncthing is an application that synchronises files across multiple
devices. This means the creation, modification or deletion of files
on one machine will automatically be replicated to other devices.

%package relaysrv
Summary:        Relay server for syncthing
Group:          Productivity/Networking/File-Sharing
Requires(pre):  pwdutils
%{?systemd_ordering}
%sysusers_requires

%description relaysrv
Syncthing requires relay servers for NAT traversal. This package
contains the necessary files for setting up a relay server, either
joined to the syncthing relay pool or private.

%prep
%autosetup -n %{name} -p1

%build
# move source archive which is extracted as "syncthing" to be "src/github.com/syncthing/syncthing"
pushd ..
install -d "src/github.com/syncthing/"
mv %{name} "src/github.com/syncthing/"%{name}
mkdir syncthing
cd "$PWD/src/github.com/syncthing/"%{name}

# set build environment, in particular use "-mod=vendor" to use the Go modules from the source archive's vendor dir
export BUILD_USER=abuild BUILD_HOST=openSUSE
export CGO_CPPFLAGS="${CPPFLAGS}" CGO_CFLAGS="${CFLAGS}" CGO_CXXFLAGS="${CXXFLAGS}" CGO_LDFLAGS="${LDFLAGS}"
export GOFLAGS="-trimpath -mod=vendor"

# build and install syncthing without automatic updates
go run build.go -no-upgrade -version v%{version} install
# build and install strelaysrv without automatic updates
go run build.go -no-upgrade -version v%{version} install strelaysrv
popd

%sysusers_generate_pre %{SOURCE3} %{name}-strelaysrv %{name}-strelaysrv-user.conf

%install
st_dir=$PWD
cd ../src/github.com/syncthing/%{name}
mv LICENSE AUTHORS CONDUCT.md CONTRIBUTING.md README.md "$st_dir"
install -Dpm 0755 bin/%{name} %{buildroot}%{_bindir}/%{name}
install -Dpm 0755 bin/strelaysrv %{buildroot}%{_bindir}/strelaysrv
install -dm 0750 %{buildroot}/%{_localstatedir}/lib/syncthing-relaysrv
install -Dpm 0644 cmd/strelaysrv/etc/linux-systemd/strelaysrv.service \
  %{buildroot}%{_unitdir}/strelaysrv.service
sed -i '/Service\]/a EnvironmentFile=-\/etc\/default/strelaysrv'    \
  %{buildroot}%{_unitdir}/strelaysrv.service
sed -i 's,^ExecStart=.*,ExecStart=/usr/bin/strelaysrv $OPTIONS,'    \
  %{buildroot}%{_unitdir}/strelaysrv.service
sed -i 's,EnvironmentFile=/etc/default/syncthing-relaysrv,EnvironmentFile=-/etc/default/syncthing-relaysrv,'    \
  %{buildroot}%{_unitdir}/strelaysrv.service
sed -i 's/^User=.*/User=strelaysrv/'    \
  %{buildroot}%{_unitdir}/strelaysrv.service
sed -i 's/^Group=.*/Group=strelaysrv/'    \
  %{buildroot}%{_unitdir}/strelaysrv.service
sed -i 's,^ReadWritePaths=.*,ReadWritePaths=/var/lib/syncthing-relaysrv,'    \
  %{buildroot}%{_unitdir}/strelaysrv.service
install -Dpm 0644 etc/linux-systemd/system/%{name}@.service        \
  %{buildroot}%{_unitdir}/%{name}@.service
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} > 120300
install -Dpm 0644 etc/linux-systemd/user/%{name}.service           \
  %{buildroot}%{_userunitdir}/%{name}.service
%endif
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysusersdir}/%{name}-relaysrv.conf

%suse_update_desktop_file -i "syncthing-ui"

%pre

%pre relaysrv -f %{name}-strelaysrv.pre
%service_add_pre strelaysrv.service

%post
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} > 120300
%systemd_user_post %{name}.service
%endif

%post relaysrv
%service_add_post strelaysrv.service

%preun
%service_del_preun %{name}@.service
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} > 120300
%systemd_user_preun %{name}.service
%endif

%preun relaysrv
%service_del_preun strelaysrv.service

%postun
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} > 120300
%systemd_user_postun %{name}.service
%endif

%postun relaysrv
%service_del_postun strelaysrv.service

%files
%license LICENSE
%doc AUTHORS CONDUCT.md CONTRIBUTING.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/syncthing-ui.desktop
%{_unitdir}/%{name}@.service
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} > 120300
%{_userunitdir}/%{name}.service
%endif

%files relaysrv
%license LICENSE
%{_bindir}/strelaysrv
%{_unitdir}/strelaysrv.service
%dir %attr(750,strelaysrv,strelaysrv) %{_localstatedir}/lib/syncthing-relaysrv
%{_sysusersdir}/%{name}-relaysrv.conf

%changelog
* Mon Jun  2 2025 Marius Kittler <marius.kittler@suse.com>
- Update to 1.29.7
  * Fixes
    fix(config): deep copy configuration defaults (fixes #9916) by @hazemKrimi in #10101
    fix(config): mark audit log options as needing restart (fixes #10099) by @marbens-arch in #10100
    fix(versioner): fix perms of created folders (fixes #9626) by @ashishbhate in #10105
    fix(syncthing): ensure both config and data dirs exist at startup (fixes #10126) by @calmh in #10127
    fix(gui): update uncamel() to handle strings like 'IDs' (fixes #10128) by @luckman212 in #10131
  * Features
    feat(gui): close a modal when pressing ESC after switching modal tabs (fixes #9489) by @hazemKrimi in #10092
  * Other
    chore(gui): add Serbian (sr) translation template by @acolomb in #10116
    build: reactivate golangci-lint by @calmh in #10118
    chore: move golangci-lint & meta to separate PR-only workflow by @calmh in #10119
    refactor: use slices.Contains to simplify code by @pullmerge in #10121
    build: process for automatic release tags by @calmh in #10133
    refactor: use slices package for sort by @mrclmr in #10132
    refactor: use slices package for sorting by @mrclmr in #10136
    docs: general notes about v2 coming by @calmh in #10135
    build: add labeler workflow for PRs by @calmh in #10143
* Tue May  6 2025 Marius Kittler <marius.kittler@suse.com>
- Update to 1.29.6
  * Version 1.29.5 was left out as it only contained a fix relevant on
    Windows
  * Bugfixes and enhancements:
    chore(lib): expose model methods to obtain progress by @pixelspark in #9886
    feat(gui): explanation to options enabled or disabled per folder type by @tomasz1986 in #9367
    fix(gui): validate device ID in canonical form (fixes #7291) by @mathias4833 in #10006
    fix(config): remove discontinued primary STUN server (fixes #10008) by @marbens-arch in #10009
    fix(stun): better error handling (ref #10008) by @calmh in #10010
    chore(config): remove discontinued secondary STUN servers (fixes #10011) by @marbens-arch in #10012
    chore(fs): speed up case normalization by @bt90 in #10013
    build(deps): update dependencies by @calmh in #10020
    feat(fs, config): add support for custom filesystem type construction by @pixelspark in #9887
    build: replace underscore in Debian version by @bt90 in #10032
    chore(model): add metric for total number of conflicts by @swenske in #10037
    fix(config): properly apply defaults when reading folder configuration by @pixelspark in #10034
    fix(config): zero filesystemtype is "basic" by @calmh in #10038
    build: push artifacts to Azure by @calmh in #10044
    chore(config): resolve primary STUN servers via SRV record by @bt90 in #10031
    chore(fs): changes to allow Filesystem to be implemented externally by @pixelspark in #10040
    fix(strings): differentiate setup(n) and set(v) up by @systemcrash in #10024
    fix(gui): mark unseen disconnected devices as inactive by @tomasz1986 in #10048
    fix(syncthing): use separate lock file instead of locking the certificate (fixes #10053) by @calmh in #10054
    feat(api, gui): allow authentication bypass for metrics by @swenske in #10045
    chore: add missing copyright in new files from infra branch by @calmh in #10055
    fix(osutil): give threads same I/O priority on Linux by @TheCreeper in #10063
    chore(syncthing): remove support for TLS 1.2 sync connections by @calmh in #10064
    chore(gui): update dependency copyrights, add script for periodic maintenance by @rasa in #10067
    chore(api): log X-Forwarded-For by @bt90 in #10035
    feat(config): add option for audit file (fixes #9481) by @marbens-arch in #10066
    chore(gui): use go list --deps for dependency list by @rasa in #10071
    fix(strelaysrv): make the session limiter session-dependent (fixes #10072) by @szu17dmy in #10073
* Tue Apr  1 2025 Marius Kittler <marius.kittler@suse.com>
- Update to 1.29.4
  * Bugfixes:
    [#9990]: Tildes break directory autocomplete
* Wed Mar 12 2025 Marius Kittler <marius.kittler@suse.com>
- Update to 1.29.3
  * Bugfixes:
    [#9929]: Unintelligible error message "setting metadata: lookup failed"
* Thu Jan 16 2025 Marius Kittler <marius.kittler@suse.com>
- Remove signature validation for now
  The signature is valid but GPG nevertheless exits with a non-zero
  return code. This problem has been discussed with upstream. The
  discussion hasn't been conclusive but it might be an issue with GPG
  itself. Until this is fixed I am removing the signature.
* Sun Jan 12 2025 Marius Kittler <marius.kittler@suse.com>
- Update to 1.29.2
  * Bugfixes:
    [#9913]: panic: string field contains invalid UTF-8 [recovered]
* Thu Jan  9 2025 Marius Kittler <marius.kittler@suse.com>
- Update to 1.29.1
  * Bugfixes:
    [#9904]: The browse API response has changed as of Syncthing v1.29.0
    [#9906]: Deadlocks randomly, occasionally
    [#9907]: The response of "pending" APIs has changed as of Syncthing v1.29.0
    [#9909]: Login into UI (Browser) not working anymore
* Mon Jan  6 2025 Marius Kittler <marius.kittler@suse.com>
- Update to 1.29.0
  * Bugfixes:
    [#9855]: GUI address unix socket broken
    [#9872]: When socket files are in a folder that needs to be synced on linux, some files were not synced until the socket files were removed
    [#9875]: Clarify log message for ignored folders
  * Other issues:
    [#9870]: Fails with Go 1.24: runtime go1.24rc1 not found in compat.yaml
* Tue Dec  3 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.28.1
  * Bugfixes:
    [#9400]: Folder overlap not detected when using tilde
    [#9590]: WebUI table column widths broken on iPhone 12 Pro Max and wider
    [#9686]: Sync status stays at 'Syncing xx%%" when remote device pauses the folder.
    [#9757]: Firefox, dark theme: device ID is hard to read
    [#9775]: Junctions as dirs doesn't work anymore
    [#9776]: Disabled checkbox panels don't respect dark theme
    [#9783]: gui: Address override not respected in fresh default config
    [#9821]: panic: runtime error: index out of range [-1]
  * Enhancements:
    [#9725]: Ignoring symbolic links when syncing on android as well
* Wed Oct 16 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.28.0
  * Bugfixes:
    [#9597]: Filenames with extended characters not ignored correctly on macOS
    [#9668]: The Web UI defaults to Filipino on Finnish browsers.
    [#9670]: lib/api: /svc/lang disregards the passed quality values
    [#9719]: Unable to establish/maintain multiple connections due to connection priority error
  * Enhancements:
    [#9715]: Lower the log level of "already connected to this device" to DEBUG (is: INFO)
* Fri Sep  6 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.12
  * Bugfixes:
    [#9677]: Syncthing v1.27.11 on desktop claims there are Local
    Additions for all folders from Android v1.27.10
* Tue Sep  3 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.11
  * Other issues:
    [#9629]: Housekeeping: chmod -x non-executable files
* Tue Aug  6 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.10
  * Bugfixes:
    [#9455]: lib/api tests unreliable, failing ~50%% of the time on Fedora Linux
    [#9499]: Data race in fakeFS (testing)
  * Remove resume service (and the related patch
    harden_syncthing-resume.service.patch) as it was removed
    upstream
* Tue Jul  2 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.9
  * Enhancements:
    [#9552]: gui: Use localised time in duration
* Tue Jun  4 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.8
  * Bugfixes:
    [#9506]: gui: Favicon not working in Firefox bookmarks
  * Enhancements:
    [#9527]: Device connection state metric
* Wed May  8 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.7
  * Bugfixes:
    [#9503]: lib/nat: panic: runtime error: index out of range
* Tue Apr  9 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.6
  * Bugfixes:
    [#9498]: Files spookily out of sync in 1.27.5
- Update bundled dependencies as usual; the update of quic-go from
  v0.41.0 to v0.42.0 will address CVE-2024-22189, see boo#1222487
* Tue Apr  2 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.5
  * Bugfixes:
    [#9371]: Deleting or renaming directories when syncing xattrs or ownership causes empty dir tree to get "put back" by ST
    [#9407]: IndexHandler can get stuck in an undesired loop
    [#9417]: CPU usage increases after folder scans (and hence, over time)
    [#9469]: Better wrapping for device and folder names in sharing lists
  * Enhancements:
    [#8972]: Open share settings when clicking 'shared with'
    [#9470]: Show encryption status for devices sharing folder
* Tue Mar  5 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.4
  * Bugfixes:
    [#9369]: Panic in ignore matching on invalid UTF-8 from filesystem watcher
    [#9435]: syncthing should be cgroup aware
  * Enhancements:
    [#9339]: File system watcher should skip ignored directories in more cases
    [#9357]: Set GOMAXPROCS quota aware in Linux containers
  * Other issues:
    [#9386]: typo in folder_sendrecv.go refrences nonexistent type dbUpdateShourtcutFile
    [#9389]: typo: Complection → Completion ?
* Tue Feb  6 2024 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.3
  * Bugfixes:
    [#9039]: Sync from Linux to Mac with ownership - Local additions after rescan
    [#9241]: Versions path does not honor tilde (~) shortcut
  * Enhancements:
    [#8616]: Add CLI completion
    [#9151]: Add "stay logged in" checkbox to login dialog
  * Other issues:
    [#9267]: Inconsistent version requirements in lib/build and lib/upgrade
    [#9313]: Different lengths used for short device IDs in UI
* Mon Feb  5 2024 Marius Kittler <marius.kittler@suse.com>
- Make syncthing-relaysrv package resolvable by using systemd users
  to create the required user and group
* Tue Jan  9 2024 Kyle Scheuing <kyle@kylescheuing.com>
- Update to 1.27.2
  * Bugfixes:
    [#9041]: cli subcommand does not use STHOMEDIR env var
    [#9183]: Filesystem watching (kqueue) is enabled … with a lot of files
    [#9274]: Missing lock in DeviceStatistics ("fatal error: concurrent map read and map write")
  * Enhancements:
    [#7406]: Add UPnP support for IPv6
  * Other Issues:
    [#9247]: Embed binary releases signing key as a file instead of hardcoding a string
    [#9287]: quic-go v0.40.1 (CVE-2023-49295)
* Mon Dec 11 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.1
  * Bugfixes:
    [#9253]: Permission error on folder causes "connection error" dialog when opening folder editor
    [#9269]: panic: nil pointer dereference in (*indexHandlerRegistry).startLocked
  * Other issues:
    [#9274]: Missing lock in DeviceStatistics ("fatal error: concurrent map read and map write")
* Tue Dec  5 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.27.0
  * Bugfixes:
    [#9179]: spurious log file in $XDG_CONFIG_HOME
    [#9189]: Discovery Returns IP
    [#9208]: Display error in 1.26 with login screen
  * Enhancements:
    [#9178]: Default config (state) dir on Unixes should be ~/.local/state/syncthing ($XDG_STATE_HOME/syncthing)
    [#9200]: Login form: login button should have an id attribute
* Wed Nov 15 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.26.1
  * Bugfixes:
    [#9208]: Display error in 1.26 with login screen
* Tue Nov  7 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.26.0
  * Bugfixes:
    [#9072]: Omitting %%s from LDAP search filter results in corrupt search filter
    [#9106]: Posting config with invalid versioner type causes panic
    [#9120]: Deduplicated files on Windows aren't treated as regular files any more (Go 1.21)
    [#9133]: Syncthing Docker container fails to start if underlying filesystem doesn't support chown
    [#9143]: traefik no longer url escape X-Forwarded-Tls-Client-Cert header
    [#9149]: Favicon is stuck in notify state
  * Enhancements:
    [#4137]: Use a real login screen + sessions instead of HTTP basic auth
* Wed Oct  4 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.25.0
  * Bugfixes:
    [#8274]: Usage report transport type is wrong for QUIC
    [#8482]: Discovery server keeps duplicate entries
    [#9019]: Web GUI loses config changes when doing multiple modifications (e.g. on slow hardware or remotely)
    [#9112]: panic: counter cannot decrease in value
    [#9123]: Hashed passwords via API are hashed again
  * Enhancements:
    [#141]: Use multiple simultaneous TCP connections
    [#5607]: Move footer links to header
* Tue Sep  5 2023 Martchus <martchus@gmx.net>
- Update to 1.24.0
  * Bugfixes:
    [#8965]: v1.23.6 introduces untrusted sharing regression
  * Enhancements:
    [#5175]: Record more performance metrics
    [#7456]: Announce IPv6 ULA
    [#7973]: Restore versions file filter should be case insensitive
    [#8767]: Check interface for FlagRunning
  * Other issues:
    [#9021]: panic: bug: ClusterConfig called on closed or nonexistent connection
    [#9034]: Build with Go 1.21 out of the box
* Wed Aug  9 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.13.7
  * Bugfixes:
    [#6597]: setLowPriority should not increase process priority when already lower (in Windows)
    [#7698]: ursrv: unrealistic uptime data, likely due to unset RTC (1970-01-01)
    [#8958]: Extended attribute filter editor should be enabled when "send extended attributes" is checked
    [#8967]: Shared With list ends with comma on 1 device
    [#9001]: relaysrv crash after some weeks of operation
  * Enhancements:
    [#8890]: Do not autoexpand tilde sign (~) to an absolute home directory path
    [#8957]: Add environment variables for --home, --conf, and --data
    [#8968]: Error for Windows invalid file names should indicate the invalid character or name part
  * Other issues:
    [#8973]: 1.23.6 docker image no longer available for linux/arm/v7
    [#8983]: Integrate govulncheck
* Tue Jul  4 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.13.6
  * Bugfixes:
    [#7638]: favicon not working Firefox & derivative browsers
    [#8899]: Omitting %%s from LDAP bind DN sends corrupted bind DN string to LDAP server
    [#8920]: Untrusted device should be disallowed from being an introducer
    [#8960]: relaysrv and discosrv docker images haven't been updated for more than year
* Tue Jun  6 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.13.5
  * This release fixes CVE-2022-46165 “Cross-site Scripting (XSS) in Web GUI”
  * Bugfixes:
    [#8503]: "syncthing cli config devices add" reflect error when using --addresses flag
    [#8764]: Ignore patterns creating during folder addition are not loaded
    [#8778]: Tests fail on Windows with Go 1.20
    [#8779]: Test cleanup fails all model tests on Windows on Go 1.20
    [#8859]: Incorrect handling of path for auto accepted folder
  * Other issues:
    [#8799]: "fatal error: checkptr: converted pointer straddles multiple allocations" in crypto tests
* Wed Apr  5 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.23.4
  - Bugfixes:
    [#8851]: "Running global migration to fix encryption file sizes" on every start
* Tue Apr  4 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.23.3
  * Bugfixes:
    [#5408]: Selection of time in versions GUI not possible without editing the string inside the textfield
    [#8277]: Mutual encrypted sharing doesn't work (both sides with password)
    [#8556]: Increased file size when sharing between encrypted devices
    [#8599]: Key generation at connect time is slow for encrypted connections
  * Enhancements:
    [#7859]: Allow sub-second watcher delay (use case: remote development)
  * Other issues:
    [#8828]: cmd/stdiscosrv: TestDatabaseGetSet flake
* Fri Mar 10 2023 Jakob Lorenz <proprietaer1@mailbox.org>
- Adding a desktop file for the Web UI
* Tue Mar  7 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.23.2
  * Bugfixes:
    [#8749]: Relay listener does not restart sometimes
  * Enhancements:
    [#8660]: GUI editor for xattr filter patterns
    [#8781]: gui: Remove duplicate Spanish translation
  * Other issues:
    [#8768]: Update quic-go for Go 1.20
* Tue Feb  7 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.23.1
  * Bugfixes:
    [#8325]: "accept: function not implemented" after upgrading to syncthing v1.20.1
* Mon Jan  2 2023 Marius Kittler <marius.kittler@suse.com>
- Update to 1.23.0
  * Bugfixes:
    [#8572]: Incorrect rescan interval on auto accepted encrypted folder
    [#8646]: Perhaps the list of devices contains empty elements
    [#8686]: Properly indicate whether a connection is "LAN" or not in the GUI
* Tue Dec  6 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.22.2
  * Bugfixes:
    [#3744]: Folders with custom icons not deletable on Windows
    [#8570]: Incorrect rescan interval when add encrypted folder with watch for changes enabled
    [#8592]: Newly added "connection type" icon and text in device info is slightly misaligned
    [#8630]: Enabling rate limit drastically reduces network performance
    [#8654]: Conflicts created on Android on files modified by other devices
    [#8657]: Xattrs not properly applied to directories, causes rescan/resync loop
    [#8661]: webgui complains about not set password in ldap mode
    [#8682]: syncthing generate command writes the deviceId to stderr instead of stdout as INFO
  * Enhancements:
    [#2771]: Add mailto link to "Show ID" dialog, for sending device ID via email
    [#7703]: Show if devices have not connected in a long time
    [#8638]: Use healtcheck endpoint for docker
    [#8686]: LAN detection via subnetmask
  * Other issues:
    [#8601]: Build fails due to setting xattrs that affect SELinux, "permission denied"
    [#8679]: Bump quic-go
* Wed Nov  2 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.22.1
  * Bugfixes:
    [#8084]: Scope ID should be filtered out of IPv6 addresses when using Remote GUI
    [#8569]: Periodic connection losses to webui because docker image doesn't support upgrade
    [#8594]: Extended attributes are only synced one way
  * Enhancements:
    [#3987]: Private relay server with authentication
    [#8244]: Show connection type in Remote Devices
    [#8430]: Add HTTP health check without using API Token
* Tue Oct  4 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.22.0
  * Bugfixes:
    [#3868]: gui: Auto select of device ID is broken on Internet Explorer
    [#7068]: "Restore Versions" GUI breaks when path exists as both directory and file
    [#7965]: Trash Can File Versioning always throws errors on restore (even when succeeded)
    [#7988]: Unexpected cleanup behavior for Simple File Versioning
    [#8529]: WebGUI is displayed incorrectly on "tablet sized" screens
  * Enhancements:
    [#2698]: Sync extended file attributes on supported file systems
    [#7603]: WebUI tooltip inconsistencies
    [#8506]: macOS Monterey 12.5.1 aliases break after sync
* Tue Sep  6 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.21.0
  * Bugfixes:
    [#8219]: REST API: db/completion no output when one folder is paused
    [#8479]: Panic in failure reporting
  * Enhancements:
    [#1329]: Add support for syncing ownership of files
    [#7981]: Show likely status of disconnected devices
    [#8296]: Auto-accepted receive-encrypted folders should have more sensible defaults
    [#8323]: Show internally used paths in the GUI for debugging
    [#8448]: Remove "restart on wakeup" functionality
* Wed Aug  3 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.20.4
  * Bugfixes:
    [#7458]: Syncthing announces address of interface which is down
    [#8479]: Panic in failure reporting
  * Enhancements:
    [#8007]: Support listing the discovered devices using the cli
* Tue Jul  5 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.20.3
  * Bugfixes:
    [#8369]: Shared device names are missing from "Edit Folder -> Sharing"
    [#8376]: Chrome Autofill Breaks Authentication
    [#8386]: Ignore patterns with wildcard and non-ASCII characters don't work as expected
  * Enhancements:
    [#8393]: Warn if two devices are introducers to each other
* Thu Jun  9 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.20.2
  * Bugfixes:
    [#7289]: TCP port 0 is announced in the LAN beacon
    [#8314]: https://relays.syncthing.net/endpoint contains non-valid URLs with spaces
    [#8355]: Upgrading from v1.19.2 to v1.20.x now requires chmod for syncing files
  * Enhancements:
    [#8264]: Include default ignore patterns in the GUI's advanced configuration editor
    [#8310]: Indicate folders / devices where the remote end is paused.
* Wed May  4 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.20.1
  * Bugfixes:
    [#8320]: Spurious failure of new connections ("unknown (newer?) version of the protocol" etc)
* Tue May  3 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.20.0
  * Bugfixes:
    [#7855]: Watching for changes using too many system resources on BSDs (kqueue)
    [#8020]: Dangling symlink prevents filesystem watcher on Solaris
    [#8232]: Missing include file endlessly spams log
    [#8258]: The latest version does not support go1.18 compilation!!
    [#8261]: TypeError: Cannot read properties of null (reading 'status') in the GUI after killing Syncthing
  * Enhancements:
    [#8202]: Indicate folders / devices where the remote end has not accepted sharing.
    [#8282]: Change default log format to include date
  * Other issues:
    [#8279]: Simplify tests using T.TempDir
* Tue Apr  5 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.19.2
  * Enhancements:
    [#8180]: Make error message upon reaching the free space quota more clear
* Wed Mar  2 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.19.1
  * Bugfixes (1.19.1):
    [#7850]: junctionsAsDirs requires folder pause and resume to trigger
    [#7924]: notify: File mode change events not emitted on MacOS/FSEvents watcher
    [#8083]: Device ID should be read-only and "nearby devices" should be hidden when adding a new pending device
    [#8143]: Behavior of discovery server doesn't match documentation
    [#8145]: Folder ID not editable in add folder dialog
  * Enhancements (1.19.1):
    [#7942]: Improve error message about folder marker outside of folder
    [#8130]: CLI: add command to print pending folders offered by specific device
  * Bugfixes (1.19.0):
    [#8103]: API: /rest/system/connections has misleading "total" entries
  * Enhancements (1.19.0):
    [#7428]: Add ignore patterns to folder defaults
    [#8090]: Allow specifying ports in --generate
* Fri Jan 14 2022 Marius Kittler <marius.kittler@suse.com>
- Update to 1.18.6
  * Enhancements:
    [#8050]: Display a warning when the ignore delete option is enabled
    [#8068]: Request: show pending devices/folders in CLI
* Tue Dec  7 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.18.5
  * Bugfixes:
    [#7715]: Deleted encrypted files don't show up as locally changed in web UI
  * Enhancements:
    [#7115]: Use CRLF instead of LF in config.xml and .stignore on Windows
    [#8014]: Send TLS SNI to relay server
    [#8021]: Provide a way to preset GUI credentials with password hashing
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_strelaysrv.service.patch
  * harden_syncthing-resume.service.patch
  * harden_syncthing@.service.patch
* Tue Nov  2 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.18.4
  * Bugfixes:
    [#7991]: Encryption trailer not updated on shortcut
    [#7994]: Index "out of sync with reality" on receive-encrypted folder
    [#8000]: stdiscosrv + strelaysrv systemd services not restarting on upgrade
    [#8012]: Not retrying to sync when a new connection is established
  * Enhancements:
    [#4293]: make "Reduced by ignore patterns" label act like "editIgnoresButton"
* Wed Oct  6 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.18.3
  * Bugfixes:
    [#7853]: gui: Superfluous quotes
    [#7935]: Panic after POST /rest/system/reset
  * Enhancements:
    [#7940]: "Currently Shared With Devices" list in the folder Sharing tab should be sorted alphabetically
* Sun Sep 26 2021 Fusion Future <qydwhotmail@gmail.com>
- Use /var/lib/syncthing-relaysrv in strelaysrv.service (boo#1190877).
* Tue Sep  7 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.18.2
  * Bugfixes:
    [#7827]: The error message "given name ... differs from filesystem name ..." does not help users to resolve the issue
    [#7893]: Updating ignores blocks GUI when IO slots are unavailable
* Thu Aug  5 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.18.1
  * Bugfixes:
    [#7704]: Changing folder type from receive encrypted to a different type corrupts the database
    [#7706]: Delete Unexpected Items in receive encrypted folder is unable to delete ".stfolder.removed-*"
    [#7740]: Incorrect local state when using negated patterns inside ignored parent folder on both sides
    [#7809]: Syncthing attemps IPv4 addresses for quic6:// peers
    [#7839]: Not exposed string for translation
    [#7845]: Strings unavailable for translation
* Fri Jul  9 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.18.0
  * Bugfixes:
    [#7708]: irreversible Local Additions after re-adding the same folder as Receive Only
    [#7731]: Scan due to watcher can not found local change while modify file to empty
    [#7733]: TypeError: Cannot read property ‘urAccepted’ of undefined
    [#7741]: Out-of-sync state of zero-byte files is not reflected on peers
  * Enhancements:
    [#7700]: Add rest endpoint(s) to dismiss pending folder/device invitations
    [#7705]: Accepting a receive encrypted folder share should prompt the user to input a password
    [#7722]: Database GC can block for a long time
    [#7724]: Ensure encryption to untrusted on new, trusted device on an existing folder
    [#7742]: Use defaults for missing fields on the config rest API
    [#7743]: Show discovery and listener status when not failed
* Tue Jun  1 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.17.0
  * This release deprecates TLS 1.2 for sync connections; other side should
    be Syncthing 1.3.0 or newer, or see
    insecureAllowOldTLSVersions.
  * Bugfixes:
    [#7592]: Web UI doesn't handle long machine names well
    [#7593]: ChaCha priority detection logic broken
    [#7608]: Files ignored on one remote do not get synced
    [#7649]: Incorrect local and global states after ignoring and unignoring files
    [#7673]: bug: cli subcommand is stuck on non-interactive shell
    [#7677]: UTF-8 normalization doesn't work on macOS
    [#7685]: CLI: strconv.ParseInt error when adding new device via CLI
    [#7699]: Sharing receive encrypted folder as receive encrypted with yet another device creates conflicts
  * Enhancements:
    [#7471]: Improve UDP hole punching
    [#7580]: Improve logging for service failures
    [#7594]: Consider removing support for TLS <1.3 on sync connections
    [#7600]: Fast connect to new devices following config update
    [#7636]: Improve QUIC performance
* Sat May 29 2021 Fabian Niepelt <fniepelt@takios.de>
- Fix User, Group, EnvironmentFile and ReadWritePaths in systemd.service unit
* Fri May 14 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.16.1:
  * fixes for other distributions only
* Tue May  4 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.16.0
  * This release adds untrusted / encrypted devices for public testing. It
    should still be considered beta / testing-only.
  * Bugfixes:
    [#7026]: panic: key not found when repairing DB
    [#7379]: "Warning, this path is a subdirectory of an existing folder" does not appear when editing only folder label
    [#7533]: Remote completion on untrusted devices is incorrect
    [#7548]: Upgrading syncthing-relaysrv to 1.15.0 fails in post-installation
    [#7551]: QUIC: failed to determine receive buffer size: doesn't have a SyscallConn
    [#7557]: Encrypted folder(s) on Windows reported as "Unexpected Objects"
    [#7568]: panic: runtime error: slice bounds out of range [24:3]
    [#7584]: Folder label missing from folder path when adding new folders
  * Enhancements:
    [#109]: Support for file encryption (e.g. non-trusted servers)
    [#3322]: GUI "Out of sync" modal uses massive amounts of CPU in browser
    [#7520]: Ask for confirmation before reverting/overriding a folder
* Wed Apr  7 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.15.0/1.15.1
  * This release fixes a vulnerability where Syncthing and the relay server
    can crash due to malformed relay protocol messages (CVE-2021-21404); see
    GHSA-x462-89pf-6r5h. (boo#1184428)
  * This release updates the CLI to use subcommands and adds the subcommands
    cli (previously standalone stcli utility) and decrypt (for offline
    verifying and decrypting encrypted folders).
  * With this release we invite everyone to test the "untrusted (encrypted)
    devices" feature. You should not use it yet on important production
    data. Thus UI controls are hidden behind a feature flag. For more
    information, visit:
    https://forum.syncthing.net/t/testing-untrusted-encrypted-devices/16470
* Wed Mar  3 2021 Marius Kittler <marius.kittler@suse.com>
- Update to 1.14.0
  * This release adds configurable device and folder defaults.
  * The output format of the /rest/db/browse endpoint has changed.
* Wed Feb  3 2021 Dirk Müller <dmueller@suse.com>
- update to 1.13.1:
  * This release adds configuration options for min/max connections (see
    https://docs.syncthing.net/advanced/option-connection-limits.html) and
    moves the storage of pending devices/folders from the config to the
    database (see https://docs.syncthing.net/dev/rest.html#cluster-endpoints).
  * Bugfixes
  * Official builds of v1.13.0 come with the Tech Ui, which is impossible to
    switch back from
* Sun Jan 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.12.1:
  * Invalid names are allowed and "auto accepted" in folder root path on Windows
  * Sometimes indexes for some folders aren't sent after starting Syncthing
  * [Untrusted] Remove Unexpected Items leaves things behind
  * Wrong theme on selection
  * Quic spamming address resolving
  * Deleted locally changed items still shown as locally changed
  * Allow specifying remote expected web UI port which would generate a href somewhere
  * Ignore fsync errors when saving ignore files
* Tue Dec  1 2020 Marius Kittler <marius.kittler@suse.com>
- Update to 1.12.0
  - The 1.12.0 release
  - adds a new config REST API.
  - The 1.11.0 release
  - adds the sendFullIndexOnUpgrade option to control whether
    all index data is resent when an upgrade is detected, equivalent
    to starting Syncthing with --reset-deltas. This
    (sendFullIndexOnUpgrade=true) used to be the behavior in previous
    versions, but is mainly useful as a troubleshooting step and
    causes high database churn. The new default is false.
* Tue Oct  6 2020 Marius Kittler <marius.kittler@suse.com>
- Update to 1.10.0
  - This release adds the config option announceLANAddresses to enable
    (the default) or disable announcing private (RFC1918) LAN IP addresses
    to global discovery.
* Tue Sep  8 2020 Marius Kittler <marius.kittler@suse.com>
- Update to 1.9.0
  - This release adds the advanced folder option caseSensitiveFS
    (https://docs.syncthing.net/advanced/folder-caseSensitiveFS.html) to
    disable the new safe handling of case insensitive filesystems.
* Tue Aug 25 2020 Marius Kittler <marius.kittler@suse.com>
- Fix Leap build by requiring at least Go 1.14
* Tue Aug 18 2020 Marius Kittler <marius.kittler@suse.com>
- Prevent the build system to download Go modules which would require an
  internet connection during the build
- Update to 1.8.0
  - The 1.8.0 release
  - adds the experimental copyRangeMethod config on folders, for use on
    filesystems with copy-on-write support. Please see
    https://docs.syncthing.net/advanced/folder-copyrangemethod.html for
    details.
  - adds TCP hole punching, used to establish high performance TCP
    connections in certain NAT scenarios where only relay or QUIC
    connections could be used previously.
  - adds a configuration to file versioning for how often to run cleanup.
    This defaults to once an hour, but is configurable from very
    frequently to never.
  - The 1.7.0 release performs a database migration to optimize for clusters
    with many devices.
  - The 1.6.0 release performs a database schema migration, and adds the
    BlockPullOrder, DisableFsync and MaxConcurrentWrites folder
    options to the configuration schema. The LocalChangeDetected event no
    longer has the action set to added for new files, instead showing modified
    for all local file changes.
  - The 1.5.0 release changes the default location for the index database under
    some circumstances. Two new flags can also be used to affect the
    location of the configuration (-config) and database (-data)
    separately. The old -home flag is equivalent to setting both of these
    to the same directory. When no flags are given the following logic is
    used to determine the data location:
    If a database exists in the old default location, that location is
    still used. This means existing installations are not affected by this
    change.
    If $XDG_DATA_HOME is set, use $XDG_DATA_HOME/syncthing.
    If ~/.local/share/syncthing exists, use that location.
    Use the old default location.
* Wed Apr  8 2020 Martin Rey <mrey@suse.com>
- Update to 1.4.2:
  - Bugfixes:
  - #6499: panic: nil pointer dereference in usage reporting
  - Other issues:
  - revert a change to the upgrade code that puts unnecessary
    load on the upgrade server
* Tue Apr  7 2020 Martin Rey <mrey@suse.com>
- Update to 1.4.1:
  - Bugfixes:
  - #6289: "general SOCKS server failure" since syncthing 1.3.3
  - #6365: Connection errors not shown in GUI
  - #6415: Loop in database migration "folder db index missing"
    after upgrade to v1.4.0
  - #6422: "fatal error: runtime: out of memory" during database
    migration on QNAP NAS
- Enhancements:
  - #5380: gui: Display folder/device name in modal
  - #5979: UNIX socket permission bits
  - #6384: Do auto upgrades early and synchronously on startup
- Other issues:
  - #6249: Remove unnecessary RAM/CPU stats from GUI
* Tue Mar 17 2020 Martin Rey <mrey@suse.com>
- Update to 1.4.0:
  - Important changes:
  - New config option maxConcurrentIncomingRequestKiB
  - Replace config option maxConcurrentScans with
    maxFolderConcurrency
  - Improve database schema
  - Bugfixes:
  - #4774: Doesn't react to Ctrl-C when run in a subshell
    with -no-restart (Linux)
  - #5952: panic: Should never get a deleted file as needed when
    we don't have it
  - #6281: Progress emitter uses 100%% CPU
  - #6300: lib/ignore: panic: runtime error: index out of range
    [0] with length 0
  - #6304: Syncing issues, database missing sequence entries
  - #6335: Crash or hard shutdown can case database
    inconsistency, out of sync
  - Enhancements:
  - #5786: Consider always running the monitor process
  - #5898: Database performance: reduce duplication
  - #5914: Limit folder concurrency to improve performance
  - #6302: Avoid thundering herd issue by global request limiter
* Tue Mar 10 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Change the Go build requirement to a more flexible
  "golang(API) >= 1.12".
* Thu Feb  6 2020 Marius Kittler <marius.kittler@suse.com>
- Disable automatic updates (which do not work anyways unless you
  run Syncthing as user root)
* Tue Feb  4 2020 Martin Rey <mrey@suse.com>
- Update to 1.3.4:
  - Bugfixes:
  - #4570: Negative percentage and data to sync
  - #5867: Progress bar not visible
  - #6044: Clicking "Save" in options says "You have unsaved
    changes" when changing automatic upgrade setting
  - #6213: Tone down STUN logging a bit
  - #6222: Connection Error on Listing More Locally Changed Files
  - #6234: Docker image uses wrong path for default folder
  - #6240: GUI: ignore patterns path is one row too low
  - #6263: Panics due to database being closed
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Tue Jan  7 2020 Martin Rey <mrey@suse.com>
- Update to 1.3.3:
  - Bugfixes:
  - #6133: Race condition in restarting folder
  - #6139: Some sync errors get cleared despite them still being
    valid
  - Enhancements:
  - #5887: Upgrade Button Does Not Have Confirmation Dialog
  - #6057: "Nearby devices" links should look more like links
    (mouse pointer)
  - #6190: Do not create .stignore if there are no ignore
    patterns
* Wed Dec  4 2019 Martin Rey <mrey@suse.com>
- Update to 1.3.2:
  - Bugfixes:
  - #5810: GUI theme not changing on WebKit-based/like browsers
  - #5968: Folder "Up To Date" but has pending
    "Revert Local Changes"
  - #5980: (De)select all not working in add device dialog
  - #6027: Folder shows as "Syncing" when there is no data
    transfer
  - #6043: Cannot exit after failed startup
  - #6081: QUIC accept error loops too quickly, causing excessive
    log output
  - #6090: Pull-scan loop due to symlink traversal
  - #6093: cmd/stdiscosrv: Data race in replication
  - #6136: API + UI device last seen is empty/Never
  - #6160: Uses too much RAM when syncing large files (1.3.0+)
  - Enhancements:
    [#6056]: Improve sharing tab when there are no devices to share
    with
    [#6115]: Change Web UI based on prefers-color-scheme
* Wed Nov 13 2019 Martin Rey <mrey@suse.com>
- Update to 1.3.1:
  - Bugfixes:
  - #5993: Build information missing in discovery and relay
    server binaries
  - #5995: Usage-reported transfer stats are meaningless
  - #6008: Changed file in receive-only folder cannot be ignored
  - #6040: Shows authentication warning when listening on UNIX
    socket
  - #6049: Hostnames resolving to localhost are not considered
    'local' in remote access warning
  - Enhancements:
  - #5583: White tab in black Interface ?
  - #5627: Stalled scans need better UI representation
  - Other issues:
  - #6010: STUN server stun.voxgratia.org should be removed
- Changes from 1.3.0:
  - Bugfixes:
  - #5985: Log spam and high CPU use if #include path is wrong in
    .stignore
  - Enhancements:
  - #5138: Rate limit can be very bursty
  - #5948: Improve free space checking when syncing
  - #5966: Database performance: improve situation with huge
    databases
  - Other issues:
  - #5924: Upgrade server JSON generator
  - #5991: lib/api: TestHostCheck never finishes with Go 1.13rc2
    under Docker
  - #5999: Allow providing your own ldflags for building
- Changes from 1.2.2:
  - Bugfixes:
  - #5824: Sync Protocol Listen Address in Actions behaves badly
  - #5836: panic: chmod ...: operation not permitted
  - #5839: Prevent leaking log info into stack traces
  - #5866: No indication in GUI that Syncthing has been shut down
  - #5888: Adding/updating pending folders is inefficient
  - #5908: panic: close of closed channel in lib/syncthing when
    shutting down
  - #5920: Free space error message is unintelligeble
  - #5934: Dialing regards any established connection as
    successful / does not check device ID
  - Enhancements:
  - #5738: Avoid logging http: TLS handshake error ...
    remote error: tls: unknown certificate
  - #5940: TLS: Support x25519, reconsider elliptic curve
    priority in handshake
  - Other issues:
  - #5115: Include systemd units in stdiscosrv/strelaysrv Debian
    packages
  - #5901: TestPullInvalidIgnoredSR flakyness + data race
* Fri Aug  9 2019 Frederic Crozat <fcrozat@suse.com>
- Update to 1.2.1:
  - Bugfixes:
  - #5308: FreeBSD: Create new file does not generate a fs event.
  - #5801: panic: close of nil channel in relay client stop
  - #5803: Web UI shows confusing description on RC builds when
    upgrades are disabled
  - #5828: panic: Index update for not running folder
  - #5833: Paused folder shows filesystem watcher error
  - #5837: panic: runtime error: index out of range in recheckFile
  - #5849: Cannot concatenate external versioner template
    variables ("%%FOLDER_PATH%%/%%FILE_PATH%%")
  - #5880: panic: runtime error: invalid memory address or nil
    pointer dereference in loadIgnoreFile
  - Enhancements:
  - #5811: Download progress of folders in the UI should update
    more frequently
- Changes from 1.2.0:
  - Important notes:
  - This release does not interoperate with Syncthing 0.14.45
    or older.
  - This release adds QUIC with NAT traversal as a new transport
    protocol. TCP is usually more performant and remains the
    preferred way of connection when possible.
  - This release adds automatic crash reporting. See
    https://docs.syncthing.net/users/crashrep.html for details.
  - This release makes large / variable block size the only
    available mode of operation; small / fixed blocks are
    deprecated.
    See https://docs.syncthing.net/advanced/folder-uselargeblocks.html for details.
  - Bugfixes:
  - #4170: panic: bug: ClusterConfig called on closed or
    nonexistent connection
  - #5609: Filesystem watching failed when parent folder is not
    listable
  - #5652: Connection error after closing failed items list
    and opening another list
  - #5765: Verioner cleanup looks at the wrong time
  - #5766: Support bundle doesn't include errors list, instead
    printing Support bundle: failed to create errors.json: <nil>
  - #5770: Scan failure blocks "Rescan" button
  - #5777: Spurious need to "revert" nonexistent changes with
    Receive Only folder on Android
  - Enhancements:
  - #959: Automatic error log sending to dev. team
  - #3345: Show last connection error per discovered address
  - #5377: Use of QUIC for transport
  - #5631: Dockerfile ENTRYPOINT doesn't pass along
    extra arguments from "docker run"
  - #5697: Handle fatal watch errors gracefully
- Changes from 1.1.4:
  - Bugfixes:
  - #4613: Progress emitter doesn't start from config change
    if disabled at startup
  - #5338: Version restore not possible with custom versioning
    path set
  - #5421: WebGui: Locally Changed Items vanish when
    clicking 10|25|50
  - #5578: Filesystem watcher error when watching disk root
    directory on Windows
  - #5641: Syncthing gets stuck in a high CPU "Failed Files"
    state - Possibly a symlink issue?
  - #5649: Checking block content on unexpected request results
    doesn't work for the last block
  - #5654: Incorrect file info passed as argument to delete
    existing dir/symlink
  - #5704: Failure to fsync() files should not be fatal
  - Enhancements:
  - #1634: Use copy instead of rename for version folder on
    other file systems
  - #4531: GUI folder/device status rows should handle longer
    values nicer
  - #4586: Versioner file tagging is inconsistent
  - #4631: In-GUI restoration should be possible from trashcan
    versioner
  - #5419: File versioning across drives
  - #5659: Old sync errors should not linger while retrying
* Fri Jul 26 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Mon May 13 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.1.3:
  - Bugfixes:
  - #5332: Duplicate Files Names in Out of Sync List
  - #5456: Folder marked as "Up to Date" with failed items
  - #5578: Filesystem Watcher Error on v1.1.0
  - #5624: Simple Syncthing invocations take a long time to run
  - #5676: Systemd circular dependency prevents startup
  - Enhancements:
  - #5554: Unnecessary time precision in
    pendingFolder/pendingDevice config entries
* Wed Apr 10 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.1.1:
  - Bugfixes:
  - #5531: Flush to database based on size instead of entries
  - #5571: Dir/symlink updates overwrite conflicts & unscanned
    files
  - #5599: Default folder in v1.1.0 isn’t created with
    useLargeBlocks = true
  - Enhancements:
  - #4921: Syncthing should guard against running old versions
    with new config
  - #5065: Add support for TLS1.3
  - #5346: Systemd unit should declare after=multiuser.target
  - #5560: Change "Introduced by" icon
  - #5569: Outdated copyright notes in "About" dialog
  - Other issues:
  - #1101: Syncthing has no easter eggs
  - #5480: Better describe exposed volumes in our Docker image
* Sat Mar 23 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.1.0:
  - Bugfixes
  - #5482: minHomeDiskFreePct is still present in fresh configs
  - #5493: Monitor bug: TERM signaling not passed to syncthing
    process
  - #5557: Hashing performance degradation when using large
    blocks
  - Enhancements
  - #5365: .desktop files: desktop-entry-lacks-keywords-entry
  - #5445: User/group ownership following parent dir
  - Other issues
  - #5077: TestWatchIgnore is flaky (OpenBSD (-current) Test
    failed)
  - #5246: TestParentDeletion fails on OpenBSD
  - #5311: Update prometheus/common/expfmt to pass tests on
    go1.11
  - #5454: build.go setup problems with gomodules
  - #5495: Dockerhub Docker builds fail continously
  - #5515: Missing string from Transifex
  - API Changes
  - Change #5479 introduces the new copyOwnershipFromParent
    folder
  - configuration option. The default, false, matches the old
    behavior of
  - not copying ownership information.
  - Since change #5405, large (variable size) blocks are enabled
    by default for newly created folders.0
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Do not hide errors from useradd.
- Add %%systemd_ordering for %%service_*.
* Tue Feb 26 2019 Bernd Wachter <bernd-obs@wachter.fi>
- Package additional binaries
  * Add CLI (stcli) to main package
  * Add relay server (strelaysrv) to relaysrv subpackage
* Tue Feb 19 2019 Marius Kittler <marius.kittler@suse.com>
- Update to version 1.0.1:
  * Directory status "box" character not readable by
    screen readers / not colour blindness friendly
    (gh#syncthing/syncthing#2697).
  * "Automatic upgrades" web GUI option in pre-release versions is
    misleading (gh#syncthing/syncthing#4216).
  * Incorrectly out of synch, sequence number oddness
    (gh#syncthing/syncthing#5340).
  * Deleted files show up as failed scans
    (gh#syncthing/syncthing#5385).
  * gui: Missing icon in footer (gh#syncthing/syncthing#5389).
  * Data race in model.(*folder).startWatch()
    (gh#syncthing/syncthing#5392).
  * Scan errors about ignored files displayed in web UI
    (gh#syncthing/syncthing#5397).
  * panic: runtime error: Invalid memory address or nil pointer
    dereference in ignore.go (gh#syncthing/syncthing#5401).
  * Illegal characters in directory name on auto accept
    (gh#syncthing/syncthing#5411).
  * Consider switching to Go modules (gh#syncthing/syncthing#5148).
* Thu Jan 31 2019 Hans-Peter Jansen <hpj@urpla.net>
- Fix build with 42.3
* Tue Jan  1 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.0.0:
  * Incorrect warning when --home and path on same directory level
    (gh#syncthing/syncthing#5324).
  * Empty file field in log when normalizePath failed
    (gh#syncthing/syncthing#5369).
  * Event system can cause deadlock (gh#syncthing/syncthing#5372).
  * Option to limit max simultaneous scans
    (gh#syncthing/syncthing#2760).
  * Add hardening options to systemd units
    (gh#syncthing/syncthing#5286).
  * Show configured rate limit in the GUI
    (gh#syncthing/syncthing#5320).
  * Show list of locally changed files for receive only directories
    (gh#syncthing/syncthing#5336).
  * New chmduquesne/rollinghash breaks tests
    (gh#syncthing/syncthing#5334).
  * lib/model: TestDeregister* tests are bad
    (gh#syncthing/syncthing#5362).
* Wed Dec 26 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.14.54 (changes since 0.14.52):
  * File restore doesn't work on one directory
    (gh#syncthing/syncthing#4738).
  * Logging debugging flags stay after disabling all debug
    facilities in the web UI (gh#syncthing/syncthing#4780).
  * Disabling the minimum drive free space check on directories
    doesn't work (gh#syncthing/syncthing#5267).
  * panic: interface conversion: interface {} is map[string]string,
    not map[string]interface {} (gh#syncthing/syncthing#5270).
  * panic: runtime error: Index out of range
    (gh#syncthing/syncthing#5291).
  * Removed devices do not influnce the list of locally needed
    files (gh#syncthing/syncthing#5294).
  * strelaypoolsrv, cmd/ursrv: Google maps issue in the GUI
    (gh#syncthing/syncthing#5296).
  * panic: bug: Unknown device should already have been rejected
    (gh#syncthing/syncthing#5299).
  * Files not deleted properly when one side has ignore permissions
    set (gh#syncthing/syncthing#5323).
  * Web GUI doesn't work in older browsers
    (gh#syncthing/syncthing#5348).
  * Directory auto-complete should be case-insensitive
    (gh#syncthing/syncthing#1347).
  * Ship .desktop files (gh#syncthing/syncthing#3439).
  * Add "select all" / "deselect all" to directory and device
    sharing dialogues (gh#syncthing/syncthing#4000).
  * Should show indication of local files/directories that can't be
    scanned for whatever reason (gh#syncthing/syncthing#4480).
  * Upgrade SSL Certificate to use modern cipher
    (gh#syncthing/syncthing#5256).
  * cmd/stdiscosrv: test suite sometimes seg faults on OpenBSD
    (gh#syncthing/syncthing#5247).
  * Update to the new prometheus client API
    (gh#syncthing/syncthing#5280).
* Sat Nov 17 2018 sor.alexei@meowr.ru
- Update to version 0.14.52:
  * "Revert Local Changes" button stays when the file causing it is
    deleted (gh#syncthing/syncthing#5130).
  * Unscanned/conflicting files are overwritten/removed in niche
    cases (gh#syncthing/syncthing#5194).
  * Watcher fails due to filepath.EvalSymlinks error
    (FindFirstFile) (gh#syncthing/syncthing#5226).
  * Directory restart can leave several directory instances running
    (gh#syncthing/syncthing#5233).
  * Impossible to change device name from web UI
    (gh#syncthing/syncthing#5249).
  * CheckFolderHealth no longer wakes up the drive at index
    exchange (gh#syncthing/syncthing#2497).
  * Disable GUI and make API available on a unix socket
    (gh#syncthing/syncthing#3616).
  * "Support bundle" download (gh#syncthing/syncthing#5142).
  * Exit with code zero when run with -help
    (gh#syncthing/syncthing#5193).
  * Move to Fork-Awesome from Font-Awesome
    (gh#syncthing/syncthing#5236).
* Tue Oct  9 2018 sor.alexei@meowr.ru
- Update to version 0.14.51:
  * Scanning and deletes should be processed even when above the
    free space limit (gh#syncthing/syncthing#2370).
  * panic: nil pointer dereference when unpausing directories
    (gh#syncthing/syncthing#5078).
  * cmd/stdiscosrv: Not enough traffic breaks replication between
    discovery servers (gh#syncthing/syncthing#5117).
  * Parent directories of unignored files keep being included and
    immediately ignored again (gh#syncthing/syncthing#5127).
  * Progress updates are ignored for send only directories
    (gh#syncthing/syncthing#5131).
  * cmd/stdiscosrv: Should not allow localhost addresses
    (gh#syncthing/syncthing#5151).
  * panic: bug: Notify backend is processing a change outside of
    the filesystem root (gh#syncthing/syncthing#5183).
  * Permanently notify about initial connection requests
    (gh#syncthing/syncthing#2291).
  * Reduce unnecessary synchronising / database traversal
    (gh#syncthing/syncthing#4782).
  * GUI authentication using LDAP (gh#syncthing/syncthing#5163).
  * Suture services should not survive panics
    (gh#syncthing/syncthing#4758).
  * Run directory tests in temporary directories
    (gh#syncthing/syncthing#5110).
* Wed Sep 26 2018 fgerling@suse.com
- Update to version 0.14.50
  Bugfixes:
    (gh#syncthing/syncthing#5038): Repeating INFO: UPnP parse: unrecognized UPnP device of type upnp:rootdevice
    (gh#syncthing/syncthing#5063): panic: cannot start already running folder
    (gh#syncthing/syncthing#5073): lib/logger: tests fail due to compilation error with go 1.11
    (gh#syncthing/syncthing#5089): Invalid files shouldn't affect global state
    (gh#syncthing/syncthing#5144): Tests fail on Go 1.11 / Windows
    (gh#syncthing/syncthing#5149): Index updates lost
  Other issues:
    (gh#syncthing/syncthing#3595): stdiscosrv: Doesn't build on Solaris
    (gh#syncthing/syncthing#5043): root on symlinked path causes panic when using "Watch for changes"
  This release includes initial support for "receive only" folders.
* Fri Aug 10 2018 bwiedemann@suse.com
- Update to version 0.14.49
    Bugfixes:
    (gh#syncthing/syncthing#4925): Deleted files within deleted directories aren't detected with FS watcher
    (gh#syncthing/syncthing#4944): Edit Folder UI displays default "Full Rescan Interval (s)" value instead of the actual one
    (gh#syncthing/syncthing#4981): Race on folder restart
    (gh#syncthing/syncthing#4983): Impossible to edit folder with path "/"
    (gh#syncthing/syncthing#4990): Incorrect large block size chosen for large files on 32 bit archs
    (gh#syncthing/syncthing#4994): Database schema from the future should be rejected
    (gh#syncthing/syncthing#5002): v0.14.48 panic: runtime error: index out of range
    (gh#syncthing/syncthing#5025): Stuck in CPU consuming accept loop when out of file descriptors
    (gh#syncthing/syncthing#5050): Filesystem watcher doesn't notify changes on Windows when the file size remains the same
    Enhancements:
    (gh#syncthing/syncthing#4863): Snap package could use removable-media slot
    (gh#syncthing/syncthing#4953): Speed up delete propagation when it's not a rename
    (gh#syncthing/syncthing#4969): Executable files edited on Windows should retain execute bit on Unixes
    (gh#syncthing/syncthing#4977): Disable rescan button while scanning instead of hiding it
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 0.14.48 (changes since 0.14.46):
  * Local host header check is too restrictive
    (gh#syncthing/syncthing#4815).
  * Unclear error message about failed watcher when running out of
    inotify watches (gh#syncthing/syncthing#4833).
  * Don't show a warning when a file from a paused directory is
    requested (gh#syncthing/syncthing#4870).
  * Zeroed local/global "state" (local files untouched) and remote
    file deletion with root Windows symlink
    (gh#syncthing/syncthing#4875).
  * Pausing on introducer removes device on other devices
    (gh#syncthing/syncthing#4897).
  * API returns empty response if non-existing files are #included
    (gh#syncthing/syncthing#4901).
  * Syncthing recreates the directories for deleted/missing
    "Folders" (gh#syncthing/syncthing#4903).
  * .stignore is accidentaly overwritten by web UI on slow machines
    (gh#syncthing/syncthing#4915).
  * GUI unresponsive or unusable with many directories or devices
    (gh#syncthing/syncthing#4918).
  * "Watching for Changes" dialogue undismissable
    (gh#syncthing/syncthing#4941).
  * Recent Changes shows empty directory label
    (gh#syncthing/syncthing#4947).
  * Bandwidth throttling per remote device
    (gh#syncthing/syncthing#4516).
  * Add UI for filesystem watcher (gh#syncthing/syncthing#4552).
  * Don't show ignored files in the "global changes" list
    (gh#syncthing/syncthing#4823).
  * Global change log should indicate directory
    (gh#syncthing/syncthing#4828).
  * Support variable sized blocks
    (gh#syncthing/syncthing#4807).
  * Thousand separator for numbers in GUI
    (gh#syncthing/syncthing#4896).
  * Make all tests Go 1.10 caching compatible
    (gh#syncthing/syncthing#4749).
* Wed May 30 2018 marius.kittler@suse.com
- Fix build command / prevent Syncthing to update itself
  Arguments go before commands so both -version and -no-upgrade
  were previously ignored resulting in Syncthing trying to update
  itself without permissions (boo#1095169).
* Tue Apr 17 2018 jengelh@inai.de
- Drop redundant wording from descriptions.
* Tue Apr 17 2018 sor.alexei@meowr.ru
- Update to version 0.14.46:
  * Replacing a directory with a symlink or vice versa is buggy
    (gh#syncthing/syncthing#2571).
  * Inaccessible files during scan are marked as deleted
    (gh#syncthing/syncthing#4573).
  * Send only directories out of synch due to ignored items
    (gh#syncthing/syncthing#4616).
  * A file deleted from all nodes may exist in the "out of synch"
    list (gh#syncthing/syncthing#4627).
  * Relay server doesn’t make outgoing HTTPS requests from its bind
    address (gh#syncthing/syncthing#4745).
  * The list of out of synch items from remote device is not
    displayed (gh#syncthing/syncthing#4759).
  * Env var for db metadata in help text differs from code
    (gh#syncthing/syncthing#4764).
  * Doesn't connect when multiple remote devices are using the
    same relay (gh#syncthing/syncthing#4778).
  * Scan on absolute path creates incorrect absolute duplicate file
    infos (gh#syncthing/syncthing#4799).
  * Panic in FS watcher in FreeBSD 8.3
    (gh#syncthing/syncthing#4806).
* Sat Mar 17 2018 sor.alexei@meowr.ru
- Update to version 0.14.45:
  * panic: bug: removed more than added
    (gh#syncthing/syncthing#4659).
  * Ignore pattern beginning with "#" does not match subpaths
    (gh#syncthing/syncthing#4680).
  * Ignore patterns in web UI aren't reloaded if only comments
    change (gh#syncthing/syncthing#4689).
  * Global is different from local state when ignoring files
    (gh#syncthing/syncthing#4701).
  * Fix basicfs_watch_tests being flaky
    (gh#syncthing/syncthing#4687).
  * Remove KCP (gh#syncthing/syncthing#4737).
* Fri Feb 23 2018 sor.alexei@meowr.ru
- Update to version 0.14.44:
  * Panic when connecting to device with auto accept and paused
    directories (gh#syncthing/syncthing#4634).
  * List of files needed on remote were not wrapped at word
    boundaries (gh#syncthing/syncthing#4636).
  * It was impossible to run non-release builds without deadlock
    detectors (gh#syncthing/syncthing#4644).
  * Fix UTF-8 normalisation not working correctly on ZFS
    (gh#syncthing/syncthing#4649).
  * Fix upgrade system showing an error on RCs in some cases
    (gh#syncthing/syncthing#4654).
  * Fix sparse files with zero blocks not closing when pulling
    (gh#syncthing/syncthing#4657).
  * Fix remote device out of synch items showing "0 items, ~0 B"
    (gh#syncthing/syncthing#4668).
  * GUI for .stversion restoration (gh#syncthing/syncthing#2599).
  * Log entries showing IP addresses now show the connection type
    (gh#syncthing/syncthing#4499).
  * Set background priority / niceness
    (gh#syncthing/syncthing#4628).
  * Fix arguments to fs.CreateSymlink being mixed up
    (gh#syncthing/syncthing#4567).
  * More scalable global discovery (gh#syncthing/syncthing#4618).
  * lib/model test failed with "ThreadSanitizer failed to allocate
    0x200000 (2097152) bytes" with Go 1.9.2
    (gh#syncthing/syncthing#4653).
  * Fix spurious "é" in GUI (gh#syncthing/syncthing#4663).
  * Should clean out generated testdata in lib/model/testdata
    (gh#syncthing/syncthing#4706).
* Thu Feb  1 2018 bwiedemann@suse.com
- Override BUILD_HOST to make build reproducible (boo#1084909)
* Thu Jan 11 2018 jengelh@inai.de
- Replace marketing blurb with a software description.
* Thu Jan 11 2018 kbabioch@suse.com
- Update to version 0.14.43:
  * Path completion in the new directory dialogue does not work
    anymore (gh#syncthing/syncthing#4475).
  * Fd leak when temp file cannot be truncated
    (gh#syncthing/syncthing#4593).
  * Panic: runtime error related to KCP
    (gh#syncthing/syncthing#4605).
  * UI for debug levels and log access
    (gh#syncthing/syncthing#2644).
  * GUI should indicate which files are out of synchronisation on
    remote devices (gh#syncthing/syncthing#4369).
  * Keep enough counters and state in the database to avoid initial
    database traversal (gh#syncthing/syncthing#4400).
  * Should understand “socks” in addition to “socks5” in proxy URLs
    (gh#syncthing/syncthing#4515).
  * Contribute kcp-go changes/features and/or fix tests
    (gh#syncthing/syncthing#4407).
  * Update vendored github.com/minio/sha256-simd for AVX512 support
    (gh#syncthing/syncthing#4585).
  * Update vendored x/sys/unix for dragonfly
    (gh#syncthing/syncthing#4615).
* Wed Jan  3 2018 sor.alexei@meowr.ru
- Update to version 0.14.42:
  * Discovering new files in a deleted directory does not resurrect
    the directory (gh#syncthing/syncthing#4475).
  * "Panic: interface conversion: *errors.errorString is not
    net.Error" after restart (gh#syncthing/syncthing#4561).
  * Auto-accept shared directories from trusted devices
    (gh#syncthing/syncthing#2299).
  * Empty directories in .stversions should be removed
    (gh#syncthing/syncthing#4406).
  * Human readable errors on attempted deletion of a non-empty
    directory (gh#syncthing/syncthing#4476).
  * Add confirmation on the Remove Folder / Device button
    (gh#syncthing/syncthing#4543).
* Tue Dec  5 2017 sor.alexei@meowr.ru
- Update to version 0.14.41:
  * Devices with ignored files stay "synchronising" forever
    (gh#syncthing/syncthing#623).
  * No Global Discovery without Synch Protocol Listen Address
    (gh#syncthing/syncthing#4418).
  * Local network classification doesn't always work
    (gh#syncthing/syncthing#4421).
  * Hashed GUI password should not be rehashed
    (gh#syncthing/syncthing#4458).
  * Pulls not triggered correctly on reconnection
    (gh#syncthing/syncthing#4504).
  * A symlink/file replacement doesn't work properly
    (gh#syncthing/syncthing#4505).
  * File/directory replacement doesn't work properly
    (gh#syncthing/syncthing#4506).
  * Logging at info level and above should always include context
    (gh#syncthing/syncthing#4510).
  * Panic in "pfilter" package on 32 bit architectures
    (gh#syncthing/syncthing#4537).
  * Allow synchronising read-only directories as
    "Master Directories" (gh#syncthing/syncthing#1126).
  * "Global Changes" button is confusing, retitle to
    "Recent Changes" (gh#syncthing/syncthing#4326).
  * Dial device addresses in parallel
    (gh#syncthing/syncthing#4456).
  * Avoid lots and lots of announced addresses in the presence of
    symmetric NAT (gh#syncthing/syncthing#4519).
  * Split transport usage reporting per stack
    (gh#syncthing/syncthing#4463).
* Fri Nov 10 2017 sor.alexei@meowr.ru
- Update to version 0.14.40:
  - Report more data part of the anonymous usage report
    (gh#syncthing/syncthing#3628)
  - Better report synchronisation errors
    (gh#syncthing/syncthing#4392).
  - Removing paused directories no longer causes a panic
    (gh#syncthing/syncthing#4405).
  - Make local IPv4 discovery more resilient against write failures
    (gh#syncthing/syncthing#4414).
  - Clearer logging around config failures at startup
    (gh#syncthing/syncthing#4431).
  - Do not complain about inability to fsync files
    (gh#syncthing/syncthing#4432).
  - Improve KCP connections (gh#syncthing/syncthing#4446).
  - Improve directory health checking
    (gh#syncthing/syncthing#4451).
  - Include built-in support for file system notifications,
    although it is disabled by default.
  - Enable by default the UDP based "KCP" protocol.
* Fri Oct 20 2017 sor.alexei@meowr.ru
- Update to version 0.14.39:
  * Removing paused directories no longer triggers a crash
    (gh#syncthing/syncthing#4357).
  * Add further security related HTTP headers
    (gh#syncthing/syncthing#4360).
  * Improve info level logging in some cases
    (gh#syncthing/syncthing#4375).
  * Improve GUI tooltips in chromium based browsers
    (gh#syncthing/syncthing#4377).
  * Add -device-id command line switch
    (gh#syncthing/syncthing#4387).
  * Failure to upgrade directory markers from file to directory
    type is no longer fatal.
* Wed Sep 20 2017 sor.alexei@meowr.ru
- Update to version 0.14.38:
  * KCP connections are now more stable
    (gh#syncthing/syncthing#4063, gh#syncthing/syncthing#4343)
  * Hashing benchmarks are skipped if a manual selection has
    been forced (gh#syncthing/syncthing#4348).
  * Relay server RAM usage has been reduced
    (gh#syncthing/syncthing#4245).
* Thu Sep 14 2017 sor.alexei@meowr.ru
- Update to version 0.14.37 (changes since 0.14.32):
  * Relative version paths are now correctly relative to the
    directory path (gh#syncthing/syncthing#4188).
  * Remote devices now show bytes remaining to synchronise
    (gh#syncthing/syncthing#4227).
  * Editing ignore patterns no longer incorrectly shows included
    patterns (gh#syncthing/syncthing#4249).
  * The new directory dialogue now suggests a default path.
    Adjustable via advanced config defaultFolderPath
    (gh#syncthing/syncthing#2157).
  * The build script no longer sets -installsuffix by default
    (gh#syncthing/syncthing#4272).
  * Prevent a vulnerability that allows file overwrite via
    versioned symlinks (boo#1074428, gh#syncthing/syncthing#4286).
  * Symlinks are deleted from versioned directories on startup
    (gh#syncthing/syncthing#4288).
  * Directory paths are no longer reset when editing a directory
    without a label (gh#syncthing/syncthing#4297).
  * Better detect synchronisation conflicts that happen while
    synchronising (gh#syncthing/syncthing#3742,
    gh#syncthing/syncthing#4305).
  * Fix a crash related to a nil reference in ignore handling
    (gh#syncthing/syncthing#4300).
- Stop requiring golang.org/x/net/context.
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 0.14.32:
  * "Nearby devices" are now shown in the add device dialogue,
    avoiding the need to type their device ID
    (gh#syncthing/syncthing#4157).
  * Directories that were once ignored in a sharing request now
    actually work properly when later added manually
    (gh#syncthing/syncthing#4219).
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 0.14.31 (changes since 0.14.29):
  * Correctly clear warning "path is a subdirectory of other
    folder" in directory dialogue (gh#syncthing/syncthing#3433).
  * Conflict copies filename now includes the ID of the last device
    to change the file (gh#syncthing/syncthing#3524).
  * Directories offered by other devices can now be ignored
    (gh#syncthing/syncthing#3993).
  * Changed device name takes effect with restart; device name is
    not sent to unknown devices (gh#syncthing/syncthing#4164).
  * Correctly show CPU usage when started with -no-restart option
    (gh#syncthing/syncthing#4183).
  * Icons and directory information in local device summary is
    consistent with that in directories
    (gh#syncthing/syncthing#4100).
  * Fix a data race in KCP & STUN (gh#syncthing/syncthing#4177).
  * Ignore patterns on newly accepted directories are no longer
    erroneously inherited from an earlier added directory
    (gh#syncthing/syncthing#4203).
* Wed Jun  7 2017 sor.alexei@meowr.ru
- Update to version 0.14.29:
  * The layout of the global changes dialogue is improved
    (gh#syncthing/syncthing#3895).
  * Running as root or SYSTEM now triggers a warning recommending
    against it (gh#syncthing/syncthing#4123).
  * Changing the theme no longer causes an HTTP error
    (gh#syncthing/syncthing#4127).
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 0.14.28:
  * It is now possible to create custom event subscriptions via the
    REST API (gh#syncthing/syncthing#1879).
  * Removing large directories now uses less memory
    (gh#syncthing/syncthing#2250).
  * The minimum disc space (per directory and for the home drive)
    can now be set to an absolute value
    (gh#syncthing/syncthing#3307).
  * Pausing or reconfiguring a directory will no longer start extra
    scans. Pausing a directory stops scanning
    (gh#syncthing/syncthing#3965).
  * Ignore patterns can now be set at directory creation time, and
    for paused directories (gh#syncthing/syncthing#3996).
  * It is no longer possible to configure the GUI/API to listen on
    a privileged port using the standard settings dialogue
    (gh#syncthing/syncthing#4020).
  * The device allowed subnet list can now include negative ("!")
    entries to disallow subnets (gh#syncthing/syncthing#4096).
  * Doing "Override changes" now uses less memory
    (gh#syncthing/syncthing#4112).
- Require golang.org/x/net/context on openSUSE older than
  openSUSE Leap 15.x.
* Wed Apr 26 2017 sor.alexei@meowr.ru
- Update to version 0.14.27:
  * Devices can now have a list of allowed subnets (advanced
    config) (gh#syncthing/syncthing#219).
  * The transfer rate units can now be changed by clicking on the
    value (gh#syncthing/syncthing#234).
  * UI text explaining "Introducer" is improved
    (gh#syncthing/syncthing#1819).
  * Advanced config editor can now edit lists of things
    (gh#syncthing/syncthing#2267).
  * Directories created for new directories now obey the user umask
    setting (gh#syncthing/syncthing#2519).
  * Incoming index updates are consistency checked better
    (gh#syncthing/syncthing#4053).
* Mon Apr 10 2017 sor.alexei@meowr.ru
- Update to version 0.14.26:
  * Discovery errors are more clearly displayed in the GUI
    (gh#syncthing/syncthing#2344).
  * The language dropdown menu in the GUI is now correctly sorted
    (gh#syncthing/syncthing#3913).
  * When there are items that could not be synced, their full path
    is displayed in the GUI.
* Mon Mar 27 2017 sor.alexei@meowr.ru
- Update to version 0.14.25:
  * Improve "Pause All"/"Resume All" icons
    (gh#syncthing/syncthing#4003).
  * There are now mips and mipsle builds by default
    (gh#syncthing/syncthing#3959).
  * The "overwriting protected files" warning now correctly handles
    relative paths to the config directory
    (gh#syncthing/syncthing#3183).
  * The experimental KCP protocol for transfers over UDP has been
    merged, although it's not currently enabled by default
    (gh#syncthing/syncthing#804).
* Sat Mar 18 2017 sor.alexei@meowr.ru
- Update to version 0.14.24:
  * lib/sync: Fix a race in unlocker logging
    (gh#syncthing/syncthing#3884).
  * Make links and log messages refer to https instead of http
    where possible (gh#syncthing/syncthing#3976).
  * The default number of parallel file processing routines per
    directory is now two (previously one), and the number of
    simultaneously outstanding network requests has been increased.
  * The UI now contains buttons to pause or resume all directories
    with a single action.
* Thu Feb 16 2017 sor.alexei@meowr.ru
- Update to version 0.14.23 (changes since 0.14.21):
  * Leading and trailing spaces are no longer stripped in the GUI
    password field (gh#syncthing/syncthing#3935)
  * The GUI shows remaining amount of data to sync per directory
    (gh#syncthing/syncthing#3908).
  * There should no longer be empty entries in the global log
    (gh#syncthing/syncthing#3933).
  * Weak hashing is now by default only enabled when it makes sense
    from a performance point of view (gh#syncthing/syncthing#3938).
* Mon Feb  6 2017 sor.alexei@meowr.ru
- Update to version 0.14.21 (changes since 0.14.19):
  * There is now a warning when adding a directory that is a parent
    of an existing directory (gh#syncthing/syncthing#3197).
  * Using -logfile flag together with -no-restart now causes an
    error instead of silently failing (gh#syncthing/syncthing#3912).
  * Weak hashing is now disabled completely when the threshold
    percentage is > 100 (gh#syncthing/syncthing#3891).
  * Rate limiting now actually works on ARM64 builds again
    (gh#syncthing/syncthing#3921).
  * Fix an issue where UPnP port allocations would be incorrect
    under some circumstances (gh#syncthing/syncthing#3924).
  * Weak hashing is a bit faster and allocates less memory.
  * The hashing performance reported at startup now includes weak
    hashing.
  * The GUI "network error" dialogue no longer shows up as easily
    in some scenarios when using Syncthing behind a reverse proxy.
* Mon Jan 16 2017 sor.alexei@meowr.ru
- Update to version 0.14.19:
  * Changing bandwidth rate limits now takes effect immediately
    without restart (gh#syncthing/syncthing#3846)
  * The event log (-audit) can now be directed to stderr for
    piping into an another application
    (gh#syncthing/syncthing#3859).
  * A panic on directory listing at startup has been fixed
    (gh#syncthing/syncthing#3584).
  * When a directory is deleted, the .stfolder marker is also
    removed. The ignore file and .stversions directory are
    retained, if present (gh#syncthing/syncthing#3857).
  * Several scenarios where a device would get stuck with
    'not a directory' errors are now handled again
    (gh#syncthing/syncthing#3819).
  * Third party copyrights in the about box are now more up to
    date (gh#syncthing/syncthing#3839).
  * Hashing performance has been improved
    (gh#syncthing/syncthing#3861)
* Fri Jan  6 2017 sor.alexei@meowr.ru
- Update to version 0.14.18:
  * Fix connections to older Syncthing versions being no longer
    closed due to an unmarshalling message:
    'proto: wrong wireType = 2 for field BlockIndexes'
    (gh#syncthing/syncthing#3855).
* Tue Dec 27 2016 sor.alexei@meowr.ru
- Update to version 0.14.17:
  * Panics caused by corrupt on disc database are now better
    explained in the panic message (gh#syncthing/syncthing#3689).
  * Statically configured device addresses without port number now
    correctly defaulted to port 22000 again
    (gh#syncthing/syncthing#3817).
  * Inotify clients no longer cause 'invalid subpath' errors to be
    displayed (gh#syncthing/syncthing#3829).
  * Directories can now be paused (gh#syncthing/syncthing#215).
  * "Master" directories are now called "send only" in order to
    standardise on a terminology of sending and receiving changes
    (gh#syncthing/syncthing#2679).
  * Pausing devices and directories now persists across restarts
    (gh#syncthing/syncthing#3407).
  * A rolling checksum is used to identify and reuse blocks that
    have moved within a file (gh#syncthing/syncthing#3527).
  * Syncthing allows setting the type-of-service field on outgoing
    packets, configured by the advanced setting "trafficClass"
    (gh#syncthing/syncthing#3790).
  * Which device introduced another device is now visible in the
    GUI (gh#syncthing/syncthing#3809).
- Remove syncthing-go-1.4-compat.patch: becoming impossible to fix.
* Fri Dec 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.16:
  * Fix a regression introduced in v0.14.14: an 'invalid subpath'
    error on syncthing-inotify full directory sync trigger
    (gh#syncthing/syncthing#3829).
* Sat Dec 17 2016 sor.alexei@meowr.ru
- Update to version 0.14.15 (changes since 0.14.13):
  * Fix a security issue resulted in Syncthing accepting index
    entries for files like '../../foo', thus resulting in a path
    above the configured directory.
  * Fix a security issue resulted in symlinks be used to trick
    Syncthing and escape constraints of the configured directory by
    creating a symlink 'foo -> ../../' and then requesting the
    contents of 'foo/something' (boo#1016161).
    Syncing symlinks between v0.14.14+ and previous versions will
    not work.
  * The build no longer requires Go 1.7
    (gh#syncthing/syncthing#3753).
  * The wording in the GUI around "last file received" is now
    clearer (gh#syncthing/syncthing#3769).
- Remove syncthing-0.14.13-go-1.6-compat.patch: fixed upstream.
- Add syncthing-go-1.4-compat.patch: Fix Go 1.4 compatibility.
* Wed Dec  7 2016 sor.alexei@meowr.ru
- Update to version 0.14.13:
  * Improve CPU usage when scanning (gh#syncthing/syncthing#3394).
  * Fix writing config and .stignore files on filesystems without
    chmod support (gh#syncthing/syncthing#2472).
  * Language selector now stays above the bottom bar
    (gh#syncthing/syncthing#3758).
- Add syncthing-0.14.13-go-1.6-compat.patch: Fix Go 1.6 and older
  compatibility (commit 0dcf2f1).
* Mon Nov 28 2016 sor.alexei@meowr.ru
- Update to version 0.14.12:
  * A data race in the code that caused test failures, and possibly
    other inconsitencies, has been resolved
    (gh#syncthing/syncthing#3737).
  * Links in warning messages are now clickable in the GUI
    (gh#syncthing/syncthing#3241).
  * Files are now synced to the drive before committed to database,
    to avoid possible inconsistencies if a power failure occurs
    during syncing (gh#syncthing/syncthing#3711).
  * Log entries now mention directories by label in addition to the
    ID (gh#syncthing/syncthing#3724).
  * The default directory now has the directory ID "default" again,
    simplifying initial setup.
  * Retries for misconfigured relay setups are slowed down somewhat
    to be kinder on our relay pool infrastructure.
* Wed Nov 16 2016 sor.alexei@meowr.ru
- Update to version 0.14.11 (changes since 0.14.9):
  * Display of global and local state is clearer, especially in the
    presence of ignores (gh#syncthing/syncthing#3623).
  * GUI does not show "failed items" unless there are items that
    have failed (gh#syncthing/syncthing#3647).
  * Introducers can now remove devices that they introduced
    (gh#syncthing/syncthing#1015).
  * Syncthing now correctly reconnects to staticly configured
    relays (gh#syncthing/syncthing#3726).
  * strelaysrv: No longer crash with 'panic: send on closed channel'
    (gh#syncthing/syncthing#3718).
  * strelaysrv: Binding to a specific address now works better
    (gh#syncthing/syncthing#3682).
  * Directory information in the GUI now uses icons and tooltips
    (gh#syncthing/syncthing#3710).
  * Fixes to questionmark and asterisk handling in ignore patterns.
  * Re-add the "Black" theme.
  * Add debugging options for deadlocks.
* Sun Oct 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.9:
  * Documentation PDFs are fixed (gh#syncthing/syncthing#3651).
  * Browser error on first startup doesn't happen as easily anymore
    (gh#syncthing/syncthing#3619).
  * Syncthing compiles in Go versions older than 1.7 again
    (gh#syncthing/syncthing#3664).
  * Adding a directory using Long UNC path no longer causes stack
    overflow (but don't do that, it's not necessary)
    (gh#syncthing/syncthing#3577).
  * Update translations.
* Sat Oct  8 2016 sor.alexei@meowr.ru
- Update to version 0.14.8:
  * The monitor process now detects crashes due to the new hashing
    package and disables it on subsequent launch
    (gh#syncthing/syncthing#3613).
  * The two hash packages are benchmarked on startup and the
    fastest on is selected (gh#syncthing/syncthing#3614).
  * Directories are now correctly shown as out of sync when they
    miss only deleted files (gh#syncthing/syncthing#3588).
  * UPnP handling is corrected in the case where more than one
    router is detected (gh#syncthing/syncthing#3578).
  * Patterns with terminal slash (e.g., "dir/") now correctly
    ignore directory contents (gh#syncthing/syncthing#3639).
* Thu Sep 29 2016 sor.alexei@meowr.ru
- Update to version 0.14.7:
  * Faster (i.e., less CPU intensive) hashing on some Intel and
    ARM64 CPUs.
  * A more refined dark theme.
  * CORS headers in the API.
  * Updated set of default discovery servers.
  * Fix deadlock on device removal (gh#syncthing/syncthing#3596).
* Sat Sep 10 2016 sor.alexei@meowr.ru
- Update to version 0.14.6:
  * In sync percentages no longer go negative for large numbers of
    deleted files (gh#syncthing/syncthing#3496).
  * Files that were deleted and then ignored are no longer deleted
    on other devices that didn't ignore them
    (gh#syncthing/syncthing#3502).
  * Configuration is no longer moved away when perfoming an upgrade
    on a full drive (gh#syncthing/syncthing#3525).
* Tue Aug 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.5:
  * Improve completion percentage calculations
    (gh#syncthing/syncthing#3492, gh#syncthing/syncthing#3493).
  * A zero progress update interval doesn't drive up CPU usage
    during syncing any more (gh#syncthing/syncthing#3517).
  * Fix virtual modtime handling, now master directories no longer
    become spuriously out of sync (gh#syncthing/syncthing#3516).
  * Remove temporary index sorting databases from disk at startup,
    if left over after a hard stop (gh#syncthing/syncthing#3529).
  * Now automatic upgrade takes more care to not leave temporaries
    behind or remove the original in case of upgrade failure
    (gh#syncthing/syncthing#3500, gh#syncthing/syncthing#3530).
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 0.14.4:
  * Timestamps are now compared with up to nanosecond precision and
    synced with up to microsecond precision, depending on the
    filesystem in use.
  * Restart is no longer needed to remove devices, unshare or
    reconfigure directories.
  * Now in sync percentage is weighted to directory size, not just
    average of directory completion.
  * Improve accessibility in the GUI.
  * Ignores and invalid file names are now handled correctly when
    delta indexes are being used.
  * Connection switching (relay->direct) no longer causes a crash.
  * Old index databases (v0.11-v0.12 and v0.13) are now properly
    cleaned away from disk.
  * Syncthing no longer claims a connection was from an ignored
    device when the device is just unknown.
* Thu Jul 28 2016 sor.alexei@meowr.ru
- Update to version 0.14.3:
  * Devices no longer get stuck in "out of sync" after a
    disconnection.
  * Syncthing no longer crashes when a connection is lost before
    index sending has started.
  * Temporary index databases are now created in the home (config)
    directory, not the system temporary directory.
* Wed Jul 27 2016 sor.alexei@meowr.ru
- Update to version 0.14.2 (changes since 0.14.0):
  * Implement "delta indexes", a backwards compatible protocol
    enhancement. Prior to delta indexes being implemented, full
    index information was exchanged at every connection start.
    With delta indexes, only index information that has changed
    since last contact is transferred.
  * Files that grow or shrink during scanning would result in
    conflicts or inconsistent data after synchronisation.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.0:
  * Respect address family for listen addresses in Discovery
    results.
  * Base the sync protocol, local discovery protocol and database
    format on protocol buffers.
  * Quickly detect other local devices on restart in local
    discovery.
  * Fix race condition causing a deadlock on directory addition.
  * Correctly format Anonymous Usage Reporting Preview.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 0.13.10:
  * Generated directory IDs are now lower case.
  * Syncthing now uses shorter temporary file names, alleviating
    issues on encfs.
  * Event IDs seen in /rest/system/events are now sequential again.
  * Tests now pass on when building on arm64.
  * Directories are now marked "stopped" when missing a path, and
    duplicate directory IDs are not accepted.
  * A stalling TLS handshake no longer blocks the connection service.
  * The global discovery server now correctly handle IPv6 announces
    over IPv4 and vice versa.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 0.13.9 (changes since 0.13.7)
  * The layout of the out of sync items dialog has been improved.
  * Directories are now sorted by label, falling back to ID when
    required.
  * Directory name completion now works for empty names.
  * Directories can now be symbolic links also when using
    ~-relative paths.
  * The discovered device addresses are now shown for disconnected
    devices.
- Enable systemd 215+ specifics on SLE 12 SP2+ and
  openSUSE Leap 42.2+.
* Fri Jun 17 2016 jacobwinski@gmail.com
- Update to version 0.13.7:
  * Fixes the issue with the GUI being grey on startup.
- Update to version 0.13.6:
  * v0.13.5 -no-upgrade build now requires gcc.
  * Favicon should not be animated.
  * Toggling HTTP/HTTPS breaks GUI/API.
  * Understand older/newer Hello messages.
  * Warnings on relay connectivity issues are reduced.
* Fri Jun  3 2016 sor.alexei@meowr.ru
- Update to version 0.13.5:
  * vendor: Update github.com/gobwas/glob.
  * cmd/syncthing: Fix upgrade of running syncthing from CLI.
  * cmd/syncthing: Be more explicit about how assets should be
    cached.
  * gui: Extract URL from translated string.
  * lib/connections: Handle wrapped connection in SetTCPOptions.
  * lib/relay: Correctly get IP from remote addr via proxy.
  * gui: Use favicon as indication for status.
  * gui: Fix editing devices.
  * gui: Show 'scanning' on unshared directories.
  * cmd/syncthing: Re-enable auto upgrade for dev builds.
  * lib/model, lib/stats: Keep track of folder's last scan time.
* Thu May 26 2016 sor.alexei@meowr.ru
- Update to version 0.13.4 (changes since 0.13.1):
  * lib/connections: Do not resolve addresses.
  * cmd/syncthing: Enforce stricter CSRF policy on /rest GET
    requests.
  * vendor: Replace github.com/jackpal/gateway with
    github.com/calmh/gateway.
  * lib/model: Leave temp file in place when final rename fails.
  * lib/model: Track puller creation times.
  * cmd/syncthing: Correctly set, parse and compare modified time
    HTTP headers.
  * lib/util: Add secure random numbers source.
  * lib/upgrade: Prefer a minor upgrade over a major.
  * cmd/syncthing: Do not modify events.
  * lib/model: Fix wild completion percentages.
  * cmd/syncthing: Use API to generate API Key and directory ID.
  * gui: Update translations.
  * Verbose log output (-verbose) and audit log (-audit) now
    contain information about changes to local files.
* Thu May 19 2016 liedke@rz.uni-mannheim.de
- Update to version 0.13.1:
  * lib/config: Don't migrate non-HTTPS-URL discovery servers to new
    path
  * gui, lib: Add missing licenses
  * lib/connections: Correctly add port to portless tcp:// URLs
* Wed May 18 2016 jengelh@inai.de
- Drop unnecessary systemd install-time dependencies. [bnc#980389]
  Only pass template units to preun (disable); no other actions
  are defined for them.
* Tue May 17 2016 sor.alexei@meowr.ru
- Update to version 0.13.0:
  * Devices now announce files that are in progress of being
    downloaded, in addition to those that are already complete.
    This means a device can serve parts of a file to other devices
    before it has completed the download itself.
  * Directory labels are now distinct from the directory ID.
    The intention is for the label to be human readable and for the
    ID to be machine readable and unique. When upgrading,
    directory IDs are not changed. However when creating new
    directories Syncthing will suggest a random, unique directory
    ID.
  * When receiving a connection attempt from an unknown device
    Syncthing will now show the name of that device, not only it's
    ID.
  * Syncthing will now manage port mappings on NAT-PMP compliant
    routers, in addition to the existing UPnP support.
  * Ignored files can now be tagged with the prefix (?d) to
    indicate that Syncthing may delete these files if they remain
    when deleting a directory. Ignore patterns use less memory by
    default.
  * The address for sync connections, both the listening side and
    for remote devices, can now be made IPv4- or IPv6-only. Use the
    tcp4:// or tcp6:// schemes to specify one or the other. The
    default tcp:// is still dual stack. Additionally, relays are
    now treated as listen addresses and set in the same
    configuration setting.
  * The directory settings dialog has been cleaned up.
  * The environment variable ALL_PROXY_NO_FALLBACK can be set to
    disable falling back to direct connections in the absence of a
    working proxy.
  * The "Syncing" complete percentage for remote devices may
    erroneously display more than 100%% (i.e. 156%% or 297%%) while a
    remote device is still synchronising.
  * Many, many bug fixes.
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 0.12.23:
  * lib/upgrade: Enforce limits on download archives.
  * lib/upgrade: Auto upgrade signature should cover version & arch.
  * gui: angular and angular-translate updates.
* Sat Apr 16 2016 sor.alexei@meowr.ru
- Update to version 0.12.22 (boo#976937):
  * cmd/syncthing: Skip a calculation if timediff is zero.
* Fri Mar 25 2016 sor.alexei@meowr.ru
- Update to 0.12.21:
  * lib/model: Correct handling of multiple subs when scanning.
  * lib/model: Properly handle deleting multiple files when doing
    scans with subs.
  * Clarify UI stuff.
  * Increase contrast for readonly form controls in dark theme.
  * ui: Improve layout of footer on narrow screens.
  * lib/relay/client: Log relay client messages.
  * ui: Better accessibility for directory & device panels.
* Sun Mar  6 2016 sor.alexei@meowr.ru
- Update to 0.12.20:
  * Fix description-contains-tabs and improve description.
  * ui: Add a lock icon to the directory title for easy overview.
  * ui: Add html tooltips (title) to the directory path and
    syncthing version elements.
  * systemd: Add syncthing-resume.service.
  * Only test with -race on supported platforms.
* Thu Feb 18 2016 sor.alexei@meowr.ru
- Update to 0.12.19:
  * Return "No such object in the index" when /rest/db/file gets
    called on something that doesn't exist.
  * Swap the corsMiddleware and the csrfMiddleware to the
    unauthenticated OPTIONS requests are first processed.
  * Report versioning usage in usage report.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.12.18 (changes since 0.12.16):
  * Add -paths option to print config, key, database paths.
  * Handle null case for invalid ng-model value.
  * Use dialer in relay checks.
  * Minor refactoring.
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to 0.12.16:
  * Don't require restart for usage reporting changes.
  * Avoid spurious scans with inotify package.
* Sun Jan 17 2016 sor.alexei@meowr.ru
- Update to 0.12.15 (changes since 0.12.12):
  * Add support for themes.
  * Don't leak sendIndexes on disconnect.
  * Always run relaying when enabled.
  * Update 'Edit' menu to 'Action' menu.
  * Handle race within the job queue.
  * Improve API/GUI shutdown handling.
  * Don't crash on directory remove while pulling.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Update to 0.12.12:
  * Update kardianos/osext.
  * Change default max conflicts to 10.
  * Do not conflict copy conflict copies.
  * Do not allow in use CSRF tokens to expire.
  * Add relaying to main settings dialog.
  * Do not resolve destination address until we need to.
  * More fine grained locking in discovery cache.
  * Add STNODEFAULTFOLDER envvar to skip default directory
    creation on new install.
- Remove Go marcos usage for now.
* Thu Jan  7 2016 sor.alexei@meowr.ru
- Update to 0.12.11:
  * Remove windows specialisation from osutil.GetLans.
  * Ensure loaded config is free of duplicate devices.
  * Show device ID QR code from edit dialog.
  * Don't warn about failed ignores if directory is unhealthy.
  * Detect non-standard hash algo and stop directory.
  * Disallow adding duplicate device ID in GUI.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.12.10:
  * Don't crash on stat error in ensureDir.
  * Consider tempfile when checking for free space.
  * Update kardianos/osext.
  * Remove fixed footer at first media break.
  * Update mtime of config file before upgrading.
  * Correct GUI asset dir handling.
* Sun Dec 20 2015 sor.alexei@meowr.ru
- Update to 0.12.9:
  * Example GUI override address.
  * Additional output on insufficient error.
  * Add command line option to open GUI.
  * Always exit via error select, making sure reader routine is exits.
  * Do not verify free space for files when directory
    MinDiskFreePct==0.
  * Edit device after accepting new connection.
* Mon Dec 14 2015 sor.alexei@meowr.ru
- Update to 0.12.8:
  * Correct type assertion in verbose logger, restart.
  * Remove Android hacks.
  * upnp: Use a separate error for the error unmarshalling.
* Tue Dec  8 2015 sor.alexei@meowr.ru
- Update to 0.12.7:
  * Filenames added to audit log in the LocalIndexUpdated event.
  * staticClient.connect(): don't handshake twice.
  * Fix STTRACE=http (it should use the http debug logger).
* Fri Dec  4 2015 sor.alexei@meowr.ru
- Update to 0.12.6 (changes since 0.12.4):
  * Update osext dependency.
  * Compact database on startup.
  * Do not chmod in Atomic on android.
  * Fix symlinks.
  * Generate ECDSA keys instead of RSA.
  * Take timeout into account when dialing.
  * Improve upgrade error messages.
  * Allow #urPreview to scroll in the browser.
  * New key for discovery-*-3.
  * Handle backoff on discovery.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 0.12.4:
  * Warn the user if they're running with an insecure looking setup.
  * Add remaining scanning time.
  * Handle sparse files.
  * Improved relay handling.
* Mon Nov 16 2015 sor.alexei@meowr.ru
- Update to 0.12.3:
  * Fix address list in DeviceDiscovered, add debug prints.
  * Audit logins with new LoginAttempt event.
  * More local discovery URL debugging.
  * Made upgrade-system smarter.
  * Remove directory without restart.
  * Do not dirty blockmap key between lookups.
* Tue Nov 10 2015 sor.alexei@meowr.ru
- Update to 0.12.2:
  * Change a discovery server certificate.
  * Fix "INFO: bug: uncached path call" log output on first startup.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 0.12.1:
  * Actually do negative caching on failed discovery lookups.
- Correct discovery port for SUSEfirewall rule.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 0.12.0.
* Fri Oct  2 2015 sor.alexei@meowr.ru
- Update to 0.11.26:
  * Do not check for free space on master directories.
  * Subscribing to events should not bump event ID.
  * Correctly report errors encountered parsing ignores.
  * Create missing directories when necessary ("dst stat dir: ..."
    error).
  * Add syncthing-inotify.service optional systemd dependency.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 0.11.25:
  * Fix incorrect "out of disk space" error when pulling files.
* Sun Sep  6 2015 sor.alexei@meowr.ru
- Update to 0.11.24:
  * Correctly handle (?i) in ignores.
  * Adjust defaults for number of hashers based on OS.
  * Allow fractional free space percentages.
* Sun Aug 30 2015 sor.alexei@meowr.ru
- Update to 0.11.23:
  * Do not trust response header.
  * Allow -logfile on all platforms.
* Wed Aug 26 2015 sor.alexei@meowr.ru
- Update to 0.11.22:
  * Fix events timeout errors.
- Correct TCP and UDP ports once again.
* Sun Aug 23 2015 sor.alexei@meowr.ru
- Update to 0.11.21:
  * Recover from 'corrupted or incomplete CURRENT file' etc.
  * Retain standard streams over restart.
  * Add unit test for staggered versioning.
  * Newest first should be different from oldest first.
  * Fix time zone error in staggered versioning.
* Mon Aug 17 2015 sor.alexei@meowr.ru
- Update to 0.11.20:
  * Rename 'delete' to 'remove'.
  * Fix editing device address.
  * Use grid instead of three-column.
  * Stop directory when running out of disk space.
  * Remove double slashes in directives.
  * Change to Font Awesome icon font.
- Fix systemd service for openSUSE Leap 42.x and openSUSE 13.2.
- Fix SUSEfirewall rule by setting UDP ports as UDP ports.
* Sun Aug  9 2015 sor.alexei@meowr.ru
- Update to 0.11.19:
  * Properly rename config files during integration tests.
  * Add timeout for peek.
  * Handle multiple case insensitivity prefixes in ignores.
- Add a SUSEfirewall rule.
* Sun Aug  2 2015 sor.alexei@meowr.ru
- Update to 0.11.18:
  * Use protocol provided buffers for requests.
  * Update credits for dependencies.
* Tue Jul 28 2015 sor.alexei@meowr.ru
- Update to 0.11.17:
  * Determine conflict winner based on change type and modification
    time.
  * Optionally ignore remote deletes.
  * Add devices and directories without restart.
* Sun Jul 19 2015 jacobwinski@gmail.com
- update to 0.11.16:
  * Allow #editIgnores to scroll in browser.
  * Don't let folder ID escape into HTML tag ID:s.
  * Improve info text for device addresses.
* Wed Jul 15 2015 jacobwinski@gmail.com
- Update to 0.11.15 (changes since 0.11.13):
  * Fix advanced option saving.
  * Update protocol package.
  * Update panic instructions.
  * Remove one of two emits of events.DeviceConnected.
* Mon Jul  6 2015 sor.alexei@meowr.ru
- Update to 0.11.13 (changes since 0.11.11):
  * Show FolderErrors result in UI.
  * Fix CSRF tests.
  * Fix add device button being overlapped by footer.
  * Preserve setgid bit on local directories.
  * Implement "advanced configuration" dialog.
  * Add link to home page.
  * Use bootstrap grid instead of column-count:3 for aligning
    checkboxes.
* Mon Jun 29 2015 sor.alexei@meowr.ru
- Update to 0.11.11:
  * Serialize scans and pulls.
  * Do not rename duplicate directories.
  * Trim string slices upon loading config.
  * Make ping timeout configurable.
* Wed Jun 24 2015 sor.alexei@meowr.ru
- Update to 0.11.10:
  * Do not warn about irrelevant symlinks, print path to culprit.
  * Add label next to "Last file received".
  * Correct API response when resetting a directory.
  * Do not start model until services have been added.
  * Sanitize rescan interval values.
* Tue Jun 16 2015 sor.alexei@meowr.ru
- Update to 0.11.9:
  * Start directories before GUI/API.
  * Correctly handle nil error in verbose logging.
  * More resilient broadcast handling.
  * Add trash can file versioning.
  * Correctly set and clear errors for missing directories.
* Sun Jun  7 2015 sor.alexei@meowr.ru
- Update to 0.11.8:
  * Random number is too large for 32 bit archs.
  * Silence discovery warnings.
  * Fix missing languages.
- Remove /usr/sbin/rcsyncthing: service name is syncthing@$USER.
* Mon Jun  1 2015 sor.alexei@meowr.ru
- Update to 0.11.7:
  * Change permissions of newly created files and directories.
  * Make syncthing honour both the ignorePerms and FlagNoPermBits
    settings.
  * A performance fix for transfers of large files.
* Mon May 25 2015 sor.alexei@meowr.ru
- Update to 0.11.6:
    Set permanent UPnP lease when required.
    Show date and time for web GUI notification.
    UPnP discovery results must not be collected in a background goroutine.
    Be more lenient against errors when deleting.
* Sat May 16 2015 sor.alexei@meowr.ru
- Update to 0.11.5 (changes since 0.11.3):
  * Add unit test for overriding ignored files.
  * Use MD5 hash of filename for temporary file.
  * Only restart global discovery on UPnP change if it was enabled
    to start with.
  * Virtual mtime support for environments that don't support
    altering mtimes.
* Tue May 12 2015 sor.alexei@meowr.ru
- Update to 0.11.3:
  * Do not remove the file when renaming on a case-insensitive
    platform.
  * Distinguish files with same name but different extension in
    staggered versioner.
  * Reschedule the next scan interval.
  * Wait for stdout/stderr to close.
  * Use actual release version for release note link.
  * Set the execute bit on Windows executables.
  * Trigger pull check on remote index updates.
  * Implement upnpSvc.Stop().
  * Remove system/editor specific ignores.
* Thu May  7 2015 sor.alexei@meowr.ru
- Initial package.
